@@ -6,15 +6,15 @@ use warnings;
 
 =head1 NAME
 
-App::ZFSCurses - Application namespace.
+App::ZFSCurses - L<zfscurses> backend.
 
 =head1 VERSION
 
-Version 1.200.
+Version 1.210.
 
 =cut
 
-our $VERSION = '1.200';
+our $VERSION = '1.210';
 
 =head1 MODULES
 
@@ -53,7 +53,7 @@ Patrice Clement <monsieurp at cpan.org>
 
 This software is copyright (c) 2020 by Patrice Clement.
 
-This is free software, licensed under the (three-clause) clause BSD License.
+This is free software, licensed under the (three-clause) BSD License.
 
 See the LICENSE file.
 
